pub struct Exporter<W> { /* private fields */ }Expand description
Exporter for vectors
Implementations
Sourceimpl<W> Exporter<W>
impl<W> Exporter<W>
Sourcepub fn new(w: W) -> Self
pub fn new(w: W) -> Self
Create a new vector exporter with default configurations and a writer to which the vectors will be written to.
Sourcepub fn use_binary(self) -> Self
pub fn use_binary(self) -> Self
Exports the data into binary word2vec format.
Sourceimpl<W: Write> Exporter<W>
impl<W: Write> Exporter<W>
Sourcepub fn export_space_filtered<F>(
self,
space: &VecSpace,
filter: F,
) -> Result<usize, Error>
pub fn export_space_filtered<F>( self, space: &VecSpace, filter: F, ) -> Result<usize, Error>
Exports all vectors from a VecSpace for which the given filter function returns
true
Sourcepub fn export_vectors<'a, 'b, I>(&mut self, iter: I) -> Result<usize, Error>where
I: IntoIterator<Item = Vector<'a, 'b>>,
pub fn export_vectors<'a, 'b, I>(&mut self, iter: I) -> Result<usize, Error>where
I: IntoIterator<Item = Vector<'a, 'b>>,
Export all given vectors. You have to call write_header first.
Panics:
Panics if write_header is true but none has been written